\name{pander}
\alias{pander}
\alias{pander.return}
\alias{pandoc}
\alias{pandoc.return}
\title{Generic pander method}
\usage{
  pander(x, ...)

  pandoc(x, ...)
}
\arguments{
  \item{x}{an R object}

  \item{...}{optional parameters}
}
\value{
  By default this function outputs (see: \code{cat}) the
  result. If you would want to catch the result instead,
  then call the function ending in \code{.return}.
}
\description{
  Prints an R object in Pandoc's markdown.
}
\note{
  This function can be called by \code{pander} and
  \code{pandoc} too.
}
\examples{
## Vectors
pander(1:10)
pander(letters)
pander(mtcars$am)
pander(factor(mtcars$am))

## Lists
pander(list(1,2,3, c(1,2)))
pander(list(a=1, b=2, c=table(mtcars$am)))
pander(list(1,2,3, list(1,2)))
pander(list(a = 1,2,3, list(1,2)))
pander(list('FOO', letters[1:3], list(1:5), table(mtcars$gear), list('FOOBAR', list('a', 'b'))))
pander(list(a=1, b=2, c=table(mtcars$am), x=list(myname=1,2), 56))
pander(unclass(chisq.test(table(mtcars$am, mtcars$gear))))

## Arrays
pander(mtcars)
pander(table(mtcars$am))
pander(table(mtcars$am, mtcars$gear))

## Tests
pander(ks.test(runif(50), runif(50)))
pander(chisq.test(table(mtcars$am, mtcars$gear)))
pander(t.test(extra ~ group, data = sleep))

## Models
ml <- with(lm(mpg ~ hp + wt), data = mtcars)
pander(ml)
pander(anova(ml))
pander(aov(ml))
## Dobson (1990) Page 93: Randomized Controlled Trial (examples from: ?glm)
counts <- c(18,17,15,20,10,20,25,13,12)
outcome <- gl(3,1,9)
treatment <- gl(3,3)
m <- glm(counts ~ outcome + treatment, family=poisson())
pander(m)
pander(anova(m))
pander(aov(m))

## Prcomp
pander(prcomp(USArrests))

## Others
pander(density(runif(10)))
pander(density(mtcars$hp))

## default method
x <- chisq.test(table(mtcars$am, mtcars$gear))
class(x) <- 'I heave never heard of!'
pander(x)
}
\references{
  \itemize{ \item John MacFarlane (2012): _Pandoc User's
  Guide_.
  \url{http://johnmacfarlane.net/pandoc/README.html} \item
  David Hajage (2011): _ascii. Export R objects to several
  markup languages._
  \url{http://CRAN.R-project.org/package=ascii} }
}

